#/bin/bash

#    YAATOBS - yet another arm toolchain build script
# 
#    Copyright (C) 2009  Torsten Brischalle
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/

BINUTILS_VERSION=2.19.1
GCC_VERSION=4.3.3
NEWLIB_VERSION=1.17.0
GDB_VERSION=6.8

MAKE_OPTIONS="-j 4"

BINUTILS_FLAGS="--target=arm-elf --enable-interwork --enable-multilib --disable-werror --with-float=soft"
GCC_FLAGS="--target=arm-elf --enable-interwork --enable-multilib --disable-werror --with-float=soft --enable-languages=c,c++ --with-newlib"
NEWLIB_FLAGS="--target=arm-elf --enable-interwork --enable-multilib --disable-werror --with-float=soft CFLAGS=-DREENTRANT_SYSCALLS_PROVIDED"
GDB_FLAGS="--target=arm-elf --enable-interwork --enable-multilib --disable-werror"

mkdir binutils-${BINUTILS_VERSION}-obj
mkdir gcc-${GCC_VERSION}-obj
mkdir newlib-${NEWLIB_VERSION}-obj
mkdir gdb-${GDB_VERSION}-obj

rm -rf binutils-${BINUTILS_VERSION}-obj/*
sudo rm -rf gcc-${GCC_VERSION}-obj/*
rm -rf newlib-${NEWLIB_VERSION}-obj/*
rm -rf gdb-${GDB_VERSION}-obj/*

if [ -d binutils-${BINUTILS_VERSION} ]
then
  echo "binutils already extracted"
else
  echo "extract binutils"
  tar -xjf binutils-${BINUTILS_VERSION}.tar.bz2
fi

if [ -d gcc-${GCC_VERSION} ]
then
  echo "gcc already extracted"
else
  echo "extract gcc"
  tar -xjf gcc-${GCC_VERSION}.tar.bz2
  patch gcc-${GCC_VERSION}/gcc/config/arm/t-arm-elf < gcc_thumb_interwork_patch
fi

if [ -d newlib-${NEWLIB_VERSION} ]
then
  echo "newlib already extracted"
else
  echo "extract newlib"
  tar -xzf newlib-${NEWLIB_VERSION}.tar.gz
fi

if [ -d gdb-${GDB_VERSION} ]
then
  echo "gdb already extracted"
else
  echo "extract gdb"
  tar -xjf gdb-${GDB_VERSION}.tar.bz2
fi

read -p "***** build binutils, press any key to continue *****"

cd binutils-${BINUTILS_VERSION}-obj
echo "configure binutils"
../binutils-${BINUTILS_VERSION}/configure ${BINUTILS_FLAGS} > binutils-${BINUTILS_VERSION}-cfg.txt
echo make "build binutils"
make ${MAKE_OPTIONS} > binutils-${BINUTILS_VERSION}-make.txt
sudo make install > binutils-${BINUTILS_VERSION}-inst.txt

cd ..

read -p "***** build gcc basic version, press any key to continue *****"

cd gcc-${GCC_VERSION}-obj
echo "configure gcc"
sudo ../gcc-${GCC_VERSION}/configure ${GCC_FLAGS} --with-newlib --with-headers=../newlib-${NEWLIB_VERSION}/newlib/libc/include --disable-libssp > gcc-${GCC_VERSION}-cfg.txt
echo "build gcc"
sudo make ${MAKE_OPTIONS} all-gcc > gcc-${GCC_VERSION}-make.txt
sudo make install-gcc > gcc-${GCC_VERSION}-inst.txt

cd ..

read -p "***** build newlib, press any key to continue *****"

cd newlib-${NEWLIB_VERSION}-obj
echo "configure newlib"
../newlib-${NEWLIB_VERSION}/configure ${NEWLIB_FLAGS} > newlib-${NEWLIB_VERSION}-cfg.txt
echo "build newlib"
make ${MAKE_OPTIONS} > newlib-${NEWLIB_VERSION}-make.txt
sudo make install > newlib-${NEWLIB_VERSION}-inst.txt

cd ..

read -p "***** build gcc full, press any key to continue *****"

cd gcc-${GCC_VERSION}-obj
sudo make ${MAKE_OPTIONS} all > gcc-${GCC_VERSION}-make.txt
sudo make install > gcc-${GCC_VERSION}-inst.txt

cd ..

read -p "***** Press any key to continue *****"

cd gdb-${GDB_VERSION}-obj
echo "configure gdb"
../gdb-${GDB_VERSION}/configure ${GDB_FLAGS} > gdb-${GDB_VERSION}-cfg.txt
echo "build gdb"
make ${MAKE_OPTIONS} > gdb-${GDB_VERSION}-make.txt
sudo make install > gdb-${GDB_VERSION}-inst.txt

cd ..

echo "toolchain build finished"

